@@ -336,12 +336,14 @@ SKIP:    { # https://rt.perl.org/rt3/Ticket/Display.html?id=95544
 	(my $package = basename($filename)) =~ s/\.pm$//;
 	print $fh "package $package;\n\$VERSION = '3alpha';\n1;\n";
 	close $fh;
+	eval "use lib '.'; use $package; die $package->VERSION";
+	ok ($@ =~ /3alpha/, 'Even a bad $VERSION is returned');
 	eval "use lib '.'; use $package;";
-	unlike ($@, qr/Invalid version format (non-numeric data)/,
+	unlike ($@, qr/Invalid version format \(non-numeric data\)/,
 	    'Do not warn about bad $VERSION unless asked');
-	eval "use lib '.'; use $package; warn $package->VERSION";
-	ok ($warning =~ /3alpha/, 'Even a bad $VERSION is returned:
-	    '.$warning);
+	eval "use lib '.'; use $package 1;";
+	like ($@, qr/Invalid version format \(non-numeric data\)/,
+	    'Warn about bad $VERSION when asked');
     }
 
 SKIP: 	{
